@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import ClassVar, Dict, Literal
+from typing import ClassVar, Dict, Literal, Annotated
 
 from pydantic import Field, ConfigDict
 
@@ -10,6 +10,7 @@ from mixam_sdk.item_specification.interfaces.component_protocol import member_me
 from mixam_sdk.item_specification.models.two_sided_component_support import (
     TwoSidedComponentSupport,
 )
+from mixam_sdk.utils.enum_json import enum_by_name, enum_dump_name
 
 
 class CoverComponent(TwoSidedComponentSupport):
@@ -23,7 +24,7 @@ class CoverComponent(TwoSidedComponentSupport):
         frozen=True
     )
 
-    cover_area: CoverArea = Field(
+    cover_area: Annotated[CoverArea, enum_by_name(CoverArea), enum_dump_name] = Field(
         default=CoverArea.FRONT_AND_BACK,
         alias="coverArea",
         description="The area of the cover component.",
