@@ -3,12 +3,14 @@ from __future__ import annotations
 from typing import ClassVar, Dict, Literal
 
 from pydantic import Field, ConfigDict
+from typing_extensions import Annotated
 
 from mixam_sdk.item_specification.enums.component_type import ComponentType
 from mixam_sdk.item_specification.enums.border_type import BorderType
 from mixam_sdk.item_specification.enums.frame_depth import FrameDepth
 from mixam_sdk.item_specification.interfaces.component_protocol import member_meta
 from mixam_sdk.item_specification.models.component_support import ComponentSupport
+from mixam_sdk.utils.enum_json import enum_by_name, enum_dump_name
 
 
 class FramedComponent(ComponentSupport):
@@ -23,7 +25,7 @@ class FramedComponent(ComponentSupport):
         frozen=True
     )
 
-    frame_depth: FrameDepth = Field(
+    frame_depth: Annotated[FrameDepth, enum_by_name(FrameDepth), enum_dump_name] = Field(
         default=FrameDepth.UNSPECIFIED,
         alias="frameDepth",
         description="Depth of the frame.",
@@ -31,7 +33,7 @@ class FramedComponent(ComponentSupport):
         validation_alias="d",
     )
 
-    border: BorderType = Field(
+    border: Annotated[BorderType, enum_by_name(BorderType), enum_dump_name] = Field(
         default=BorderType.WRAP_AROUND,
         alias="border",
         description="Type of border for the frame.",
