@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import ClassVar, Dict, Literal
+from typing import ClassVar, Dict, Literal, Annotated
 
 from pydantic import Field, ConfigDict
 
@@ -8,6 +8,7 @@ from mixam_sdk.item_specification.enums.component_type import ComponentType
 from mixam_sdk.item_specification.enums.sample_pack_type import SamplePackType
 from mixam_sdk.item_specification.interfaces.component_protocol import member_meta
 from mixam_sdk.item_specification.models.component_support import ComponentSupport
+from mixam_sdk.utils.enum_json import enum_by_name, enum_dump_name
 
 
 class SamplePackComponent(ComponentSupport):
@@ -21,7 +22,7 @@ class SamplePackComponent(ComponentSupport):
         frozen=True
     )
 
-    sample_pack_type: SamplePackType = Field(
+    sample_pack_type: Annotated[SamplePackType, enum_by_name(SamplePackType), enum_dump_name] = Field(
         default=SamplePackType.PRODUCTS,
         alias="samplePackType",
         description="The type of sample pack being ordered",
